@@ -6,12 +6,12 @@ function(MClist, Weights = rep(1, length(MClist)), CheckArguments = TRUE)
 
   # Metacommunities must have names
   if (is.null(names(MClist)))
-    names(MClist) <- paste("MC", 1:length(MClist), sep="")
+    names(MClist) <- paste("MC", seq_along(MClist), sep="")
   
   # Merge metacommunities Nsi
   Reduce(function(...) mergeandlabel(...), lapply(MClist, function(x) x$Nsi)) -> Gabundances
   # Suffle the colum order
-  Shuffled <- sample(1:ncol(Gabundances))
+  Shuffled <- sample(seq_len(ncol(Gabundances)))
   # Name the communities
   NumCommunities <- unlist(lapply(MClist, function(x) length(x$Ni)))
   MCnames <- rep(names(MClist), NumCommunities)
@@ -19,7 +19,7 @@ function(MClist, Weights = rep(1, length(MClist)), CheckArguments = TRUE)
   # Create shuffled MC's
   FirstC <- 1
   ShuffledMCList <- list()
-  for (i in 1:length(MClist)) {
+  for (i in seq_along(MClist)) {
     LastC <- FirstC + length((MClist[[i]])$Wi) - 1
     ShuffledMCList[[i]] <- MetaCommunity(Gabundances[, Shuffled[FirstC:LastC]], (MClist[[i]])$Wi)
     names(ShuffledMCList)[i] <- paste("MC", i, sep="")
